@@ -6,58 +6,54 @@ use warnings qw(all);
 
 use Digest::SHA qw(sha256);
 
-use Any::Moose;
-use Any::Moose qw(X::NonMoose);
+use Moo;
+use MooX::Types::MooseLike::Base qw(:all);
 extends 'HTML::TreeBuilder';
 
 use HTML::Linear::Element;
 use HTML::Linear::Path;
 
-our $VERSION = '0.015'; # VERSION
+## no critic (ProtectPrivateSubs, RequireFinalReturn)
+
+our $VERSION = '0.016'; # VERSION
 
 
 has _list       => (
-    traits      => ['Array'],
     is          => 'ro',
-    isa         => 'ArrayRef[Any]',
+    isa         => ArrayRef[InstanceOf('HTML::Linear::Element')],
     default     => sub { [] },
-    handles     => {
-        _add_element    => 'push',
-        as_list         => 'elements',
-        count_elements  => 'count',
-        get_element     => 'accessor',
-    },
 );
 
+sub _add_element { push @{shift->_list}, shift }
+sub as_list { @{shift->_list} }
+sub count_elements { 0 + @{shift->_list} }
+sub get_element { shift->_list->[shift] }
+
 
 has _shrink => (
-    traits      => ['Bool'],
-    is          => 'ro',
-    isa         => 'Bool',
-    default     => 0,
-    handles     => {
-        set_shrink      => 'set',
-        unset_shrink    => 'unset',
-    },
+    is          => 'rwp',
+    isa         => Bool,
+    default     => sub { 0 },
 );
 
+sub set_shrink { shift->_set__shrink(1) }
+sub unset_shrink { shift->_set__shrink(0) }
+
 
 has _strict => (
-    traits      => ['Bool'],
-    is          => 'ro',
-    isa         => 'Bool',
-    default     => 0,
-    handles     => {
-        set_strict      => 'set',
-        unset_strict    => 'unset',
-    },
+    is          => 'rwp',
+    isa         => Bool,
+    default     => sub { 0 },
 );
 
-
-has _uniq       => (is => 'ro', isa => 'HashRef[Str]', default => sub { {} });
+sub set_strict { shift->_set__strict(1) }
+sub unset_strict { shift->_set__strict(0) }
 
 
-has _path_count => (is => 'ro', isa => 'HashRef[Str]', default => sub { {} });
+has _uniq       => (is => 'ro', isa => HashRef[Str], default => sub { {} });
+
+
+has _path_count => (is => 'ro', isa => HashRef[Str], default => sub { {} });
 
 
 after eof => sub {
@@ -181,12 +177,10 @@ sub deparse {
     return $level;
 }
 
-no Any::Moose;
-__PACKAGE__->meta->make_immutable;
-
 1;
 
 __END__
+
 =pod
 
 =encoding utf8
@@ -197,7 +191,7 @@ HTML::Linear - represent HTML::Tree as a flat list
 
 =head1 VERSION
 
-version 0.015
+version 0.016
 
 =head1 SYNOPSIS
 
@@ -282,10 +276,9 @@ Stanislaw Pusep <stas@sysd.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Stanislaw Pusep.
+This software is copyright (c) 2013 by Stanislaw Pusep.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
