@@ -6,23 +6,26 @@ use warnings qw(all);
 
 use Digest::SHA;
 use List::Util qw(sum);
-use Any::Moose;
+use Moo;
+use MooX::Types::MooseLike::Base qw(:all);
 
 use HTML::Linear::Path;
 
-our $VERSION = '0.015'; # VERSION
+## no critic (ProtectPrivateSubs)
+
+our $VERSION = '0.016'; # VERSION
 
 
-has attributes  => (is => 'rw', isa => 'HashRef[Str]', default => sub { {} }, auto_deref => 1);
-has content     => (is => 'rw', isa => 'Str', default => '');
-has depth       => (is => 'ro', isa => 'Int', required => 1);
-has index       => (is => 'rw', isa => 'Int', default => 0);
-has index_map   => (is => 'rw', isa => 'HashRef[Str]', default => sub { {} }, auto_deref => 1);
-has key         => (is => 'rw', isa => 'Str', default => '');
-has path        => (is => 'ro', isa => 'ArrayRef[HTML::Linear::Path]', required => 1, auto_deref => 1);
-has sha         => (is => 'ro', isa => 'Digest::SHA', default => sub { new Digest::SHA(256) }, lazy => 1 );
-has strict      => (is => 'ro', isa => 'Bool', default => 0);
-has trim_at     => (is => 'rw', isa => 'Int', default => 0);
+has attributes  => (is => 'rw', isa => HashRef[Str], default => sub { {} });
+has content     => (is => 'rw', isa => Str, default => sub { '' });
+has depth       => (is => 'ro', isa => Int, required => 1);
+has index       => (is => 'rw', isa => Int, default => sub { 0 });
+has index_map   => (is => 'rw', isa => HashRef[Str], default => sub { {} });
+has key         => (is => 'rw', isa => Str, default => sub { '' });
+has path        => (is => 'ro', isa => ArrayRef[InstanceOf('HTML::Linear::Path')], required => 1);
+has sha         => (is => 'ro', isa => InstanceOf('Digest::SHA'), default => sub { Digest::SHA->new(256) }, lazy => 1 );
+has strict      => (is => 'ro', isa => Bool, default => sub { 0 });
+has trim_at     => (is => 'rw', isa => Int, default => sub { 0 });
 
 use overload '""' => \&as_string, fallback => 1;
 
@@ -30,6 +33,7 @@ use overload '""' => \&as_string, fallback => 1;
 sub BUILD {
     my ($self) = @_;
     $self->attributes({%{$self->path->[-1]->attributes}});
+    return;
 }
 
 
@@ -49,7 +53,7 @@ sub as_xpath {
     my ($self) = @_;
     my @xpath = map {
         $_->as_xpath . ($self->index_map->{$_->address} // '')
-    } ($self->path) [$self->trim_at .. $#{$self->path}];
+    } @{$self->path} [$self->trim_at .. $#{$self->path}];
     $self->trim_at and unshift @xpath, HTML::Linear::Path::_wrap(separator => '/');
     return wantarray
         ? @xpath
@@ -77,22 +81,21 @@ sub as_hash {
         $xpath
         . HTML::Linear::Path::_wrap(attribute => 'text()')
     } = $self->content
-        unless $self->content =~ m{^\s*$}s;
+        unless $self->content =~ m{^\s*$}sx;
 
     return $hash;
 }
 
 
 sub weight {
-    sum map +$_->weight, @{$_[0]->path};
+    my ($self) = @_;
+    return sum map { $_->weight } @{$self->path};
 }
 
-no Any::Moose;
-__PACKAGE__->meta->make_immutable;
-
 1;
 
 __END__
+
 =pod
 
 =encoding utf8
@@ -103,7 +106,7 @@ HTML::Linear::Element - represent elements to populate HTML::Linear
 
 =head1 VERSION
 
-version 0.015
+version 0.016
 
 =head1 SYNOPSIS
 
@@ -185,10 +188,9 @@ Stanislaw Pusep <stas@sysd.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Stanislaw Pusep.
+This software is copyright (c) 2013 by Stanislaw Pusep.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
